<?php
function cOut($text)
{
    printf("\033[32m".$text."\033[0m\n").PHP_EOL;
} // function

function cLine()
{
    print '--------------------------------------------------------------------------------'.PHP_EOL;
} // function

cOut("phpanalyze 1.1.0 by Gjero Krsteski 2010");
cOut('Uses phploc, phpcpd, pdepend, phpcs and custom-line-count to analyze your PHP-project.'.PHP_EOL);

if ($argv[1] == '--help' || $argv[1] == '--h' || $argv[1] == '-h')
{
    cOut('Options overview for your php project');
    cLine();
    cOut('phploc       measures the size');
    cOut('phpcpd       checks duplicated lines');
    cOut('phpcs        checks coding standard');
    cOut('mylc         checks lines-count');
    cOut('pdepend      generates code-analysis-chart');
    cOut('all          runs the complete analysis');
    exit;
}

if (false === isset($argv[2]))
{
    die('ERROR: Please set the path to your project that should be analyzed!'.PHP_EOL
        .' [SAMP: php analyze.php --option /path/to/your/php/project/]'.PHP_EOL);
}

if (count($argv) != 3)
{
    die('ERROR: There must be three parameters given! -option -/path/to/your/php/project/'.PHP_EOL);
}

if (false === is_dir($argv[2]))
{
    die('ERROR: The path you have specified is not available! ['.$argv[2].']'.PHP_EOL);
}

$path = escapeshellcmd($argv[2]);
$work = escapeshellcmd($argv[1]);

cOut('YOUR STATISTICS FOR: '.$path);
print PHP_EOL;

if ($work == '--phploc' || $work == '--all')
{
  cOut('MEASURES THE SIZE OF YOUR PHP PROJECT');
  cLine();
  system('phploc suffixes=php,inc '.$path, $output);
  print PHP_EOL.PHP_EOL;
}

if ($work == '--phpcpd' || $work == '--all')
{
  cOut('CHECKS DUPLICATED LINES AT YOUR PHP PROJECT ');
  cLine();
  system('phpcpd suffixes=php,inc '.$path, $output);
  print PHP_EOL.PHP_EOL;
}

if ($work == '--phpcs' || $work == '--all')
{
  cOut('CHECKS CODING STANDARD AT YOUR PHP PROJECT ');
  system('phpcs --standard=path/to/your/standard/ '.$path);
  print PHP_EOL.PHP_EOL;
}

if ($work == '--mylc' || $work == '--all')
{
  cOut('CHECKS LINES-COUNT AT YOUR PHP PROJECT ');
  cLine();
  system('find '.$path.'* -type f -name "*.php" | xargs wc -l');
  print PHP_EOL.PHP_EOL;
}

if ($work == '--pdepend' || $work == '--all')
{
  cOut('STATIC CODE ANALYSIS OF YOUR PHP PROJECT ');
  cLine();

  $statisticPath = dirname(__FILE__).'/logs/'.str_replace('/', '-', $path);
  $summaryXML    = $statisticPath.'summary.xml';
  $jdependSVG    = $statisticPath.'jdepend.svg';
  $pyramidSVG    = $statisticPath.'pyramid.svg';

  system('pdepend --suffix=php,inc '.
      '--coderank-mode=inheritance,property,method '.
      '--summary-xml='.$summaryXML.' '.
      '--jdepend-chart='.$jdependSVG.' '.
      '--overview-pyramid='.$pyramidSVG.' '.$path);

  cOut('SEE SUMMARY.XML AT: '.$summaryXML);
  cOut('SEE JDEPEND.SVG AT: '.$jdependSVG);
  cOut('SEE PYRAMID.SVG AT: '.$pyramidSVG);

  print PHP_EOL;
  cOut('REFERENCE VALUES');
  cLine();
  cOut('
  Metric        Low     Average   High

  CYCLO/LOC     0.16    0.20      0.24

  LOC/NOM       7       10        13

  NOM/NOC       4       7         10

  NOC/NOP       6       17        26

  CALLS/NOM     2.01    2.62      3.2

  FANOUT/CALLS  0.56    0.62      0.68

  ANDC          0.25    0.41      0.57

  AHH           0.09    0.21      0.32');
}
cLine();
print PHP_EOL;